;
; PICSound for external EEPROM
;
; Processor: PIC 16F84A @ 4 MHz
; Updated by Art
;

	INCLUDE	"P16F84A.INC"

	__CONFIG	b'11111111110010'	; Set Processor Configuration
	;		  1111111111----	; Code Protection off
	;	     	  ----------0---	; Power-Up Timer enabled
	;	 	  -----------0--	; Watchdog disabled
	;		  ------------10	; HS Osc

; **** Variables *********************************************************

; * Sound System *

sound_port = PORTA			; Port where the RC is connected
sound_tris = TRISA & 0x7F		; Tris for the Port
sound_primout = 2			; Primary I/O Pin of the RC
sound_secout = 3			; Secondary I/O Pin of the RC
sound_sectris = 3			; Tris Bit of the sec. I/O Pin

sound_bitcount = 0x10			; Bit - Counter

sound_len_hi = 0x12			; Counter for length of Sound-File
sound_len_lo = 0x13			;

sound_start_hi = 0x17			; Offset of Sound-File		; Set as necassary 
sound_start_lo = 0x18			;

speed = 0x19				; Sound speed

sound_len = .7499			; Length of Sound-File		"I hope you die, I hope you f**king die!"
sound_lenA = .1440			; Length of Sound-File		"Die!"
sound_lenB = .2748			; Length of Sound-File		"I hope you die."
sound_lenC = .5042			; Length of Sound-File		"I hope you f**king die!"
sound_lenD = .1330			; Length of Sound-File		"Die."

; * IC Interface *

iicbuffer = 0x14			; IIC Buffer
iicbuffercount = 0x15			; Counter of IIC rotary
iicdelaycount = 0x16			; Counter of IIC IIC Delay Loop
iicdelayus = 1				; Initialvalue of IIC Delay Loop
IICPORT = PORTB				; Port IIC
IICTRIS = TRISB				; Tris IIC
scl = 2					; IIC Bus - Clock
sda = 3					; IIC Bus - Data


; **** Reset Vector ******************************************************

	org	0x00

	clrf	INTCON			; disable all Interrupts
	goto	start			; Jump to Program entry point

; **** Interrupt Vector	**************************************************

	org	0x04

	retfie				; return - Interrupts not used in this Project

; **** M a i n p r o g r a m *********************************************

start:	bsf	STATUS,RP0		; Bank 1

	movlw	b'10001000'		; Set OPTION_REG
	; 	  1-------		; PortB Internal Pull-Up disabled
	;	  -xxx----		; Don't Care
	;	  ----1---		; Prescaler assigned to WDT
	;	  -----000		; Prescaler 1:1 
	movwf	OPTION_REG & 0x7F

	movlw	b'00000000'		; All Pins on Port A are Output
	movwf	TRISA & 0x7F

	movlw	b'00000000'		; All Pins on Port B are Output
	movwf	TRISB & 0x7F

	bcf	STATUS,RP0		; Bank 0

	clrf	PORTA			; Init Port A
	clrf	PORTB			; Init Port B


	goto	Program			;


Xstart:
	bcf	portb,1			;turn LED on
	nop				;
	nop				;
	call	iicstart		; Start IIC communication

	movlw	b'10100000'		; Load (Hardware) Address of IIC-EEProm
	call	iicwrite		; write it to IIC and wait for ACK
	btfss	STATUS,C		; C=1 = ACK received
	goto	start			; there was a problem - Restart

	movf	sound_start_hi,w	; Load Address of Sound-File (HI)
	call	iicwrite		; write it to IIC and wait for ACK
	btfss	STATUS,C		; C=1 = ACK received
	goto	start			; there was a problem - Restart

	movf	sound_start_lo,w	; Load Address of Sound-File (LO)
	call	iicwrite		; write it to IIC and wait for ACK
	btfss	STATUS,C		; C=1 = ACK received
	goto	start			; there was a problem - Restart

	call	iicstart		; Restart IIC Communication (refer to Datasheet)

	movlw	b'10100001'		; Load (Hardware) Address of IIC-EEProm
	call	iicwrite		; write it to IIC and wait for ACK
	btfss	STATUS,C		; C=1 = ACK received
	goto	start			; there was a problem - Restart

sound_main_loop:
	movlw	0x08			; Init Bit Counter
	movwf	sound_bitcount

sound_loop:
	btfss	TMR0,6			; Timer 0 >= 64 ?
	goto	sound_loop		; no, then wait for it		
	
	movf	speed,w			; ********************************* speed adjustment (.27 real time 4MHz)
	movwf	TMR0			;

; - Get Bit from IC -
	call	iicin			; set IIC to input
	bsf	IICPORT,scl		; set Clock HIGH
	call	iicdelay

	btfss	IICPORT,sda		; get 1 Bit
	goto	sound_output0		; it was 0 - output 0 to prim. Output-Pin

	btfsc	sound_port,sound_primout; check last bit
	goto	sound_last1_1		; last bit was 1

	bsf	STATUS,RP0		; Bank 1
	bsf	sound_tris,sound_sectris; Set sec. Tris to Input
	bcf	STATUS,RP0		; Bank 0
	goto	sound_last1		; finally set the primary Output-Pin to 1

sound_last1_1:
	bsf	STATUS,RP0		; Bank 1
	bcf	sound_tris,sound_sectris; Set sec. Tris to Output
	bcf	STATUS,RP0		; Bank 0
	bsf	sound_port,sound_secout	; Set sec. Output-Pin to 1

sound_last1:
	bsf	sound_port,sound_primout; it was 1 - output 1 to prim. Output-Pin

	goto	sound_nextbit		; this Bit is Done - continue with other functions

	
sound_output0:
	btfss	sound_port,sound_primout; check last bit
	goto	sound_last0_0		; last bit was 0
	
	bsf	STATUS,RP0		; Bank 1
	bsf	sound_tris,sound_sectris; Set sec. Tris to Input
	bcf	STATUS,RP0		; Bank 0

	goto	sound_last0		; finally set the primary Output-Pin to 0

sound_last0_0:
	bsf	STATUS,RP0		; Bank 1
	bcf	sound_tris,sound_sectris; Set sec. Tris to Output
	bcf	STATUS,RP0		; Bank 0
	bcf	sound_port,sound_secout	; Set sec. Output-Pin to 0

sound_last0:
	bcf	sound_port,sound_primout; it was 0 - output 0 to prim. Output-Pin

sound_nextbit:
	bcf	IICPORT,scl		; set Clock LOW

	decfsz	sound_bitcount,f	; decrement Bit Counter
	goto	sound_loop		; continue with next Bit

	decfsz	sound_len_lo,f		; decrement Length (LO)
	goto	sound_sendack		; >0 - send ACK to IIC and continue

	decfsz	sound_len_hi,f		; decrement Length (HI)
	goto	sound_sendack		; >0 - send ACK to IIC and continue

	goto	sound_end		; everything is done - exit

sound_sendack:
	call	iicsendack		; send ACK to IIC
	goto	sound_main_loop		; and continue with the Sound Main Loop


; ***************************
; ****                   ****
; **** IIC (IC) Routine ****
; ****                   ****
; ***************************
;
; V 1.00	30.11.2001
;
; iicbuffer = 0x27	; Buffer fr IIC
; iicbuffercount = 0x28	; Zhler fr IIC rotary
; iicdelaycount = 0x29	; Zhler fr IIC Verzgerungsschleife
; iicdelayus = 1	; Initialwert fr IIC Verzgerungsschleife
; IICPORT = PORTB	; Port fr IIC
; IICTRIS = TRISB	; Tris fr IIC
; scl = 1		; Interner IIC Bus - Clock
; sda = 0		; Interner IIC Bus - Data


; **** I_IICRead *********************************************************
; 						  Read a Byte from IIC
; Output: iicbuffer = received Byte
;         w = received Byte

iicread:
	call	iicin
	movlw	0x08				; 8 Bits
	movwf	iicbuffercount			; in den BufferCounter schreiben
nextbitin:
	bsf	IICPORT,scl			; Clock auf HIGH
	
	call	iicdelay
	btfss	IICPORT,sda			; is der SDA high dann skip next cmd
	goto	iicbitin0
iicbitin1:
	bsf	STATUS,C			; Carry setzen
	goto	iicbitincnt
iicbitin0:
	bcf	STATUS,C			; Carry lschen
iicbitincnt:
	rlf	iicbuffer,f			; Carry in den Buffer reinShiften

	bcf	IICPORT,scl			; Clock auf LOW
	
	
	decfsz	iicbuffercount,f		; buffer runterzhlen
	goto	nextbitin

	movf	iicbuffer,w			; buffer nach W kopieren
	
	return


; **** IICWrite ********************************************************
; 						Write a Byte to IIC
; Input:  W = Byte to send

iicwrite:
	movwf	iicbuffer				; W in den Buffer retten
	
	call	iicout
	movlw	0x08				; 8 bit lang
	movwf	iicbuffercount			; in den BufferCounter schreiben
nextbitout:
	rlf	iicbuffer,f			; nach links rollen; MSB ins  Carry
	btfss	STATUS,C			; is das C high dann skip next cmd
	goto	iicbitout0			; 0 ausgeben
iicbitout1:
	bsf	IICPORT,sda			; HIGH auf SDA
	goto	iicbitoutcnt
iicbitout0:
	bcf	IICPORT,sda			; LOW auf SDA
iicbitoutcnt:
	bsf	IICPORT,scl			; Clock HIGH
	
	call	iicdelay		
	bcf	IICPORT,scl			; Clock LOW
	

	decfsz	iicbuffercount,f		; buffer runterzhlen
	goto	nextbitout	


; **** IICwaitAck ******************************************************
; 							wait for ACK
; Output: C = 1 ACK received
;	  C = 0 no ACK reveived

iicwaitack:
	call	iicin
	bsf	IICPORT,scl			; Clock auf HIGH
	clrf	iicbuffercount			; ZhlerLO auf 0
waitack:	
	decfsz	iicbuffercount,f		; ZhlerLO runterzhlen
	goto	chksda

	bcf	STATUS,C			; Carry Lschen - Kein ACK empfangen
	bcf	IICPORT,scl			; Clock auf LOW
	
	return

chksda:
	btfsc	IICPORT,sda			; Warten bis SDA auf LOW
	goto	waitack
	bcf	IICPORT,scl			; Clock auf LOW
	bsf	STATUS,C
	
	return


; **** IICsendAck ******************************************************
; 						     send ACK to IIC

iicsendack:
	call	iicout
	bcf	IICPORT,sda			; Data auf LOW	
	bsf	IICPORT,scl			; Clock auf HIGH
	
	call	iicdelay
	bcf	IICPORT,scl			; Clock auf LOW
	
	return


; **** IICsendNAck *****************************************************
; 						   send NACK to IIC

iicsendnack:
	call	iicout
	bsf	IICPORT,sda			; Data auf HIGH
	bsf	IICPORT,scl			; Clock auf HIGH
	
	call	iicdelay
	bcf	IICPORT,scl			; Clock auf LOW
	
	return


; **** IICOut **********************************************************
; 					  set SDA-Port Pin to Output

iicout:
	bsf	STATUS,RP0			; Bank 1
	bcf	IICTRIS & 0x7f,sda		; Data auf Output
	bcf	STATUS,RP0			; Bank 0
	
	return


; **** IICIn ***********************************************************
; 					   set SDA-Port Pin to Input

iicin:
	bsf	STATUS,RP0			; Bank 1
	bsf	IICTRIS & 0x7f,sda		; Data auf Input
	bcf	STATUS,RP0			; Bank 0
	
	return


; **** IICStart ********************************************************
; 					send a Start-Condition to IIC

iicstart:
	call	iicout
	bsf	IICPORT,scl			; Clock auf HIGH
	bsf	IICPORT,sda			; Data auf HIGH
	
	call	iicdelay
	bcf	IICPORT,sda			; Data auf LOW
	
	call	iicdelay
	bcf	IICPORT,scl			; Clock auf LOW
	
	goto	iicdelay
	

; **** IICStop *********************************************************
; 					send a Stop-Condition to IIC

iicstop:
	call	iicout
	bcf	IICPORT,scl			; Clock auf LOW
	bcf	IICPORT,sda			; Data auf LOW
	
	call	iicdelay
	bsf	IICPORT,scl			; Clock auf HIGH
	
	call	iicdelay
	bsf	IICPORT,sda			; Data auf HIGH
	
	goto	iicdelay


; **** IICReset ********************************************************
; 							Reset IIC Bus

iicreset:
	call	iicout
	movlw	.18
	movwf	iicbuffercount
inextresetbit:
	bsf	IICPORT,sda			; Data auf High
	bsf	IICPORT,scl			; Clock auf High
	
	call	iicdelay
	bcf	IICPORT,scl			; Clock auf Low
	
	call	iicdelay
	decfsz	iicbuffercount,f		; Counter runterzhlen
	goto	inextresetbit
	
	return

	
; **** IICDelay **********************************************************
; 						 Delay routine for IIC

iicdelay:
	nop	
	return

sound_end:
	call	iicsendnack			; send NACK to IIC
	call	iicstop				; Stop IIC communication
	bsf	portb,1				;turn LED off
	return					;

;*************************************************************************


Program:

	movlw	.27				;
	movwf	speed				;

	clrf	sound_start_lo			;"I hope you die, I hope you f**cking die!"
	clrf	sound_start_hi			;
	movlw	high (sound_len) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_len)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;
	call	BiggerDelay			;

	call	infine				;
	call	infine				;
	call	infine				;
	call	infine				;
	call	infine				;



Xinfine:
	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BiggerDelay			;
	call	BiggerDelay			;
	call	BigDelay			;"I hope you die"
	movlw	0x00				;
	movwf	sound_start_hi			;
	movlw	0x00				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenB) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenB)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BiggerDelay			;
	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BiggerDelay			;
	call	BiggerDelay			;
	call	XBigDelay			;"I hope you f**cking die!"
	movlw	0x09				;
	movwf	sound_start_hi			;
	movlw	0x9F				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenC) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenC)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BigDelay			;
	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BigDelay			;"Die."
	movlw	0x05				;
	movwf	sound_start_hi			;
	movlw	0x1C				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenD) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenD)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BiggerDelay			;
	call	XBigDelay			;"I hope you f**cking die!"
	movlw	0x09				;
	movwf	sound_start_hi			;
	movlw	0x9F				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenC) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenC)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BiggerDelay			;
	call	BiggerDelay			;
	call	BigDelay			;"I hope you die"
	movlw	0x00				;
	movwf	sound_start_hi			;
	movlw	0x00				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenB) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenB)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;


	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.30				; change speed
	movwf	speed				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.32				; change speed
	movwf	speed				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.34				; change speed
	movwf	speed				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.20				; slow speed
	movwf	speed				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	0x17				;"Die!"
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.30				; change speed
	movwf	speed				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.35				; change speed
	movwf	speed				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.36				; change speed
	movwf	speed				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.18				; slow speed
	movwf	speed				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;


	movlw	.27				; return speed to real time
	movwf	speed				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.18				; return speed to real time
	movwf	speed				;


	call	XBigDelay			;"I hope you f**cking die!"
	movlw	0x09				;
	movwf	sound_start_hi			;
	movlw	0x9F				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenC) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenC)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.27				; return speed to real time
	movwf	speed				;

	call	BigDelay			;"Die!"
	movlw	0x17				;
	movwf	sound_start_hi			;
	movlw	0x39				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenA) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenA)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.19				; return speed to real time
	movwf	speed				;

	call	BigDelay			;"I hope you die"
	movlw	0x00				;
	movwf	sound_start_hi			;
	movlw	0x00				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenB) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenB)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.33				;
	movwf	speed				;

	call	BigDelay			;"I hope you die"
	movlw	0x00				;
	movwf	sound_start_hi			;
	movlw	0x00				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenB) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenB)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BigDelay			;"I hope you die"
	movlw	0x00				;
	movwf	sound_start_hi			;
	movlw	0x00				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenB) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenB)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	movlw	.27				; return speed to real time
	movwf	speed				;

	call	BigDelay			;"I hope you die"
	movlw	0x00				;
	movwf	sound_start_hi			;
	movlw	0x00				;
	movwf	sound_start_lo			;
	movlw	high (sound_lenB) +1		;
	movwf	sound_len_hi			;
	movlw	low (sound_lenB)+1		;
	movwf	sound_len_lo			;
	call	Xstart				;

	call	BiggerDelay			;
	call	BiggerDelay			;
	call	BigDelay			;
	call	BiggerDelay			;
	goto	Xinfine				;repeat forever



infine:	bsf	portb,1				;turn LED off (flash LED)
Loff:	call	BigDelay			;longer delay for LED off time
	call	BigDelay			;
	incfsz	iicdelaycount,f			;advance delay counter
	goto	Loff				;
	bcf	portb,1				;turn LED on
Lon:	call	BigDelay			;delay
	incfsz	iicdelaycount,f			;advance delay counter
	goto	Lon				;
	return					;keep flashing LED

BiggerDelay:
	call	YBigDelay			;
	call	YBigDelay			;
	call	YBigDelay			;
	call	YBigDelay			;
	call	YBigDelay			;
	call	YBigDelay			;
YBigDelay:
	call	XBigDelay			;
	call	XBigDelay			;
	call	XBigDelay			;
XBigDelay:
	call	BigDelay			;
	call	BigDelay			;
	call	BigDelay			;
	call	BigDelay			;
	call	BigDelay			;
	call	BigDelay			;
BigDelay:
	nop					;
	nop					;
	incfsz	iicbuffercount,f		;
	goto	BigDelay			;
	return					;

	end
